| Title: | Binary Indexed Tree |
|---|---|
| Description: | A simple implementation of Binary Indexed Tree by R. The BinaryIndexedTree class supports construction of Binary Indexed Tree from a vector, update of a value in the vector and query for the sum of a interval of the vector. |
| Authors: | Jialun Zhang, Zhilan Fan, Hang Zhang |
| Maintainer: | Jialun Zhang <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-23 05:24:53 UTC |
| Source: | https://github.com/cran/rbit |
Methods:
new(init) Initializes from a vector init.
update(location, new.val) Replaces the item at location with new.val.
query(l, r) Returns the sum of the interval [l, r].
show.BIT () Returns the Binary Indexed Tree.
show.origin() Returns the vector.
BinaryIndexedTreeBinaryIndexedTree
An object of class R6ClassGenerator of length 24.
tmp <- BinaryIndexedTree$new(c(2,3,2,5,1)) tmp$update(1,3) tmp$query(1,5) tmp$show.origin() tmp$show.BIT()tmp <- BinaryIndexedTree$new(c(2,3,2,5,1)) tmp$update(1,3) tmp$query(1,5) tmp$show.origin() tmp$show.BIT()